:mod:`maec.bundle.object_reference` Module
==========================================

.. module:: maec.bundle.object_reference

Classes
-------

.. autoclass:: ObjectReference
	:show-inheritance:
	:members:
  
.. autoclass:: ObjectReferenceList
	:show-inheritance:
	:members:


